@@ -33,8 +33,6 @@ OC.L10N.register(
     "An error occurred" : "Digwyddodd gwall",
     "Today" : "Heddiw",
     "Close" : "Cau",
-    "Share" : "Rhannu",
-    "Next week" : "Wythnos nesaf",
-    "Next month" : "Mis nesaf"
+    "Share" : "Rhannu"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
