@@ -31,6 +31,7 @@ OC.L10N.register(
     "{user} has renamed the card {before} to {card}" : "{user} muutti kortin {before} uudeksi nimeksi {card}",
     "You have added a description to card {card} in list {stack} on board {board}" : "Olet lisännyt kuvauksen kortille {card} listalla {stack} taululla {board}",
     "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} on lisännyt kuvauksen kortille {card} listalla {stack} taululla {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Olet päivittänyt kortin {card} kuvauksen listalla {stack} taululla {board}",
     "You have removed the due date of card {card}" : "Poistit eräpäivän kortilta {card}",
     "{user} has removed the due date of card {card}" : "{user} poisti eräpäivän kortilta {card}",
     "You have set the due date of card {card} to {after}" : "Asetit kortille {card} eräpäivän {after}",
@@ -61,7 +62,9 @@ OC.L10N.register(
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortin \"%s\" on \"%s\" eräpäivä on tullut vastaan.",
     "%s has mentioned you in a comment on \"%s\"." : "%s mainitsi sinut kommentissa kortilla \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Taulu \"%s\" on jaettu kanssasi käyttäjän %s toimesta.",
+    "{user} has shared {deck-board} with you." : "{user} on jakanut taulun {deck-board} kanssasi.",
     "Deck board" : "Deck-taulu",
+    "Create a new deck card" : "Luo uusi kortti",
     "Card comments" : "Kortin kommentit",
     "Finished" : "Valmistunut",
     "To review" : "Arvosteltavana",
@@ -86,6 +89,7 @@ OC.L10N.register(
     "Card not found" : "Korttia ei löydy",
     "Path is already shared with this card" : "Polku on jo jaettu tämän kortin kanssa",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päivä, päivän muodon tulee olla YYYY-MM-DD",
+    "Card details" : "Näytä kortin sisältö",
     "Add board" : "Lisää taulu",
     "Select the board to link to a project" : "Valitse projektiin linkitettävä taulu",
     "Search by board title" : "Hae taulun otsikon mukaan",
@@ -110,12 +114,14 @@ OC.L10N.register(
     "Archived cards" : "Arkistoidut kortit",
     "Add list" : "Lisää lista",
     "List name" : "Listan nimi",
+    "Active filters" : "Aktiiviset suodattimet",
     "Apply filter" : "Toteuta suodatus",
     "Filter by tag" : "Suodata tunnisteen perusteella",
     "Filter by assigned user" : "Suodata määritetyn käyttäjän mukaan",
     "Unassigned" : "Määrittämätön",
-    "Open" : "Avaa",
-    "Completed" : "Valmistui",
+    "Open and completed" : "Avoimet ja valmiit",
+    "Open" : "Avoimet",
+    "Completed" : "Valmiit",
     "Filter by due date" : "Suodata määräpäivän mukaan",
     "Overdue" : "Myöhässä",
     "Next 24 hours" : "Seuraavat 24 tuntia",
@@ -126,6 +132,8 @@ OC.L10N.register(
     "Hide archived cards" : "Piilota arkistoidut kortit",
     "Show archived cards" : "Näytä arkistoidut kortit",
     "Toggle compact mode" : "Käytä kompaktia tilaa",
+    "Hide card cover images" : "Piilota korttien kansikuvat",
+    "Show card cover images" : "Näytä korttien kansikuvat",
     "Open details" : "Avaa yksityiskohdat",
     "Details" : "Tiedot",
     "Loading board" : "Ladataan taulua",
@@ -138,6 +146,7 @@ OC.L10N.register(
     "Deleted lists" : "Poistetut listat",
     "Undo" : "Kumoa",
     "Deleted cards" : "Poistetut kortit",
+    "Share board with a user, group or team …" : "Jaa taulu käyttäjän, ryhmän tai tiimin kanssa...",
     "No participants found" : "Ei osallistujia löydetty",
     "Board owner" : "Taulun omistaja",
     "(Group)" : "(Ryhmä)",
@@ -146,6 +155,8 @@ OC.L10N.register(
     "Can manage" : "Voi hallita",
     "Owner" : "Omistaja",
     "Delete" : "Poista",
+    "Failed to create share with {displayName}" : "Jaon luonti epäonnistui kohteen {displayName} kanssa",
+    "Are you sure you want to transfer the board {title} to {user}?" : "Haluatko varmasti siirtää taulun {title} käyttäjälle {user}?",
     "Transfer" : "Siirrä",
     "Archive all cards" : "Arkistoi kaikki kortit",
     "Delete list" : "Poista lista",
@@ -159,6 +170,8 @@ OC.L10N.register(
     "Board name" : "Taulun nimi",
     "Members" : "Jäsenet",
     "Upload new files" : "Lähetä uusia tiedostoja",
+    "Share from Files" : "Jaa tiedostoista",
+    "Pending share" : "Odottava jako",
     "Add this attachment" : "Lisää tämä liite",
     "Download" : "Lataa",
     "Remove attachment" : "Poista liite",
@@ -198,10 +211,11 @@ OC.L10N.register(
     "Archive card" : "Arkistoi kortti",
     "Select Date" : "Valitse päivä",
     "Assign a tag to this card…" : "Lisää kortille tunniste...",
+    "Create a new tag:" : "Luo uusi tunniste:",
     "(group)" : "(ryhmä)",
     "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "{count} comments, {unread} unread" : "{count} kommenttia, {unread} lukematonta",
-    "Card details" : "Näytä kortin sisältö",
+    "Edit card title" : "Muokkaa kortin otsikkoa",
     "Assign to me" : "Määritä minulle",
     "Unassign myself" : "Poista määritys minulta",
     "Delete card" : "Poista kortti",
@@ -212,26 +226,33 @@ OC.L10N.register(
     "Action" : "Toiminto",
     "Shift" : "Siirrä",
     "Search" : "Etsi",
+    "Mark card as completed/not completed" : "Merkitse kortti valmiiksi/avoimeksi",
     "All boards" : "Kaikki taulut",
     "Archived boards" : "Arkistoidut taulut",
     "Shared with you" : "Jaettu kanssasi",
+    "Deck settings" : "Pakan asetukset",
+    "Show boards in calendar/tasks" : "Näytä taulut kalenterissa ja tehtävissä",
+    "Cancel edit" : "Peruuta muokkaus",
     "Board details" : "Taulun tiedot",
     "Edit board" : "Muokkaa taulua",
     "Clone board" : "Monista taulu",
     "Unarchive board" : "Kumoa taulun arkistointi",
     "Archive board" : "Arkistoi taulu",
+    "Export board" : "Vie taulu",
     "All cards" : "Kaikki kortit",
     "No notifications" : "Ei ilmoituksia",
     "Delete board" : "Poista taulu",
     "Board {0} deleted" : "Taulu {0} poistettu",
     "No reminder" : "Ei muistutusta",
     "An error occurred" : "Tapahtui virhe",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Haluatko varmasti poistaa taulun {title}? Tämä poistaa kaikki taulun tiedot, mukaan lukien arkistoidut kortit.",
     "Delete the board?" : "Poistetaanko tämä taulu?",
     "Today" : "Tänään",
     "Tomorrow" : "Huomenna",
     "Search for {searchQuery} in all boards" : "Hae ehtoja {searchQuery} kaikilta tauluilta",
     "No results found" : "Ei tuloksia",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Click to expand description" : "Laajenna kuvausta ",
+    "{nbCards} cards" : "{nbCards} korttia    ",
     "Click to expand comment" : "Napsauta laajentaaksesi kommentin",
     "Create a new card" : "Luo uusi kortti",
     "Card title" : "Kortin otsikko",
@@ -242,6 +263,9 @@ OC.L10N.register(
     "Close" : "Sulje",
     "No upcoming cards" : "Ei tulevia kortteja",
     "upcoming cards" : "tulevat kortit",
+    "New card" : "Uusi kortti",
+    "Due on {date}" : "Määräpäivä {date}",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Link to a board" : "Linkki taululle",
@@ -252,14 +276,6 @@ OC.L10N.register(
     "Maximum file size of {size} exceeded" : "Tiedoston enimmäiskoko {size} ylitetty",
     "Error creating the share" : "Virhe jakoa luotaessa",
     "Share" : "Jaa",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Kortin kuvaus</strong> Pakka-sovelluksessa on vaihtunut",
-    "Timeline" : "Aikajana",
-    "Share board with a user, group or circle …" : "Jaa taulu käyttäjän, ryhmän tai piirin ... kanssa",
-    "(Circle)" : "(Piiri)",
-    "Next week" : "Seuraava viikko",
-    "Next month" : "Seuraava kuukausi",
-    "List is empty" : "Lista on tyhjä",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Pakan käytön rajoittaminen estää merkittyjen ryhmien jäseniä luomasta omia taulujaan, mutta käyttäjät pystyvät silti käyttämään heidän kanssaan jaettuja tauluja.",
-    "Not completed" : "Ei valmis"
+    "(Circle)" : "(Piiri)"
 },
 "nplurals=2; plural=(n != 1);");
