@@ -37,6 +37,10 @@ OC.L10N.register(
     "{user} has archived card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}にカード{card}をアーカイブしました",
     "You have unarchived card {card} in list {stack} on board {board}" : "ボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user}がボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "ボード{board}のリスト{stack}で、カード{card}に完了のマークを付けました。",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user}は、ボード{board}のリスト{stack}で、カード{card}に完了のマークを付けました。",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "ボード{board}のリスト{stack}でカード{card}に未完成のマークを付けました。",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user}は、ボード{board}のリスト{stack}でカード{card}に未完成のマークを付けました。",
     "You have removed the due date of card {card}" : "カード{card}の期日を削除しました",
     "{user} has removed the due date of card {card}" : "{user}がカード{card}の期日を削除しました",
     "You have set the due date of card {card} to {after}" : "カード{card}の期日を{after}に設定しました",
@@ -116,6 +120,7 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
+    "Card details" : "カード詳細",
     "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
@@ -145,6 +150,7 @@ OC.L10N.register(
     "Filter by tag" : "タグによるフィルター",
     "Filter by assigned user" : "割当ユーザーでフィルター",
     "Unassigned" : "未割り当て",
+    "Filter by status" : "ステータスによるフィルター",
     "Open and completed" : "開いて完成",
     "Open" : "開く",
     "Completed" : "完了",
@@ -269,7 +275,6 @@ OC.L10N.register(
     "Todo items" : "Todo項目",
     "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
     "Edit card title" : "カードタイトルを編集する",
-    "Card details" : "カード詳細",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Mark as not done" : "未完成のマーク",
@@ -310,6 +315,8 @@ OC.L10N.register(
     "Show card ID badge" : "カードIDバジを表示",
     "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
     "Limit board creation to some groups" : "ボード作成は一部のグループに制限する",
+    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "これらのグループ以外のユーザーは、独自のボードを作成することはできませんが、共有されているボードで作業することはできます。",
+    "Cancel edit" : "編集をキャンセル",
     "Board details" : "ボードの詳細",
     "Edit board" : "ボードを編集",
     "Clone board" : "ボードを複製",
@@ -327,6 +334,7 @@ OC.L10N.register(
     "Only assigned cards" : "割り当てられたカードのみ",
     "No reminder" : "リマインダーなし",
     "An error occurred" : "エラーが発生しました",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "ボード{title}を削除しますか? これにより、アーカイブされたカードを含むこのボードのすべてのデータが削除されます。",
     "Delete the board?" : "ボードを削除しますか？",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
     "Today" : "今日",
@@ -334,10 +342,10 @@ OC.L10N.register(
     "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
     "No results found" : "結果が見つかりません",
-    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "デッキボード{name}\n最終更新日：{lastMod}",
     "{stack} in {board}" : "{board} 内の {stack}",
     "Click to expand description" : "説明を展開するにはクリックしてください",
+    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 作成: {created}\n* 最終変更: {lastMod}\n* {nbAttachments} 添付ファイル\n* {nbComments} コメント",
     "{nbCards} cards" : "{nbCards} カード",
     "Click to expand comment" : "コメントを展開するにはクリックしてください",
     "Create a new card" : "新しいカードを作成する",
@@ -353,6 +361,7 @@ OC.L10N.register(
     "upcoming cards" : "今後のカード",
     "New card" : "新しいカード",
     "Due on {date}" : "期間{date}",
+    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
     "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
     "Link to a board" : "ボードへのリンク",
@@ -366,18 +375,9 @@ OC.L10N.register(
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
-    "Timeline" : "タイムライン",
-    "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
     "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
     "(Circle)" : "(サークル)",
     "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
-    "Next week" : "来週",
-    "Next month" : "来月",
-    "List is empty" : "リストが空です",
-    "Limit deck usage of groups" : "デッキの使用をグループに制限",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
-    "Not completed" : "完成してないです",
     "Filter by completed" : "完成したものをフィルターする"
 },
 "nplurals=1; plural=0;");
