@@ -120,6 +120,7 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다.",
     "Personal planning and team project organization" : "개인 기획 및 팀 프로젝트 구성",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck은 Nextcloud와 통합된 팀의 개인 계획 및 프로젝트 구성을 목표로 하는 칸반 스타일 구성 도구입니다.\n\n\n- 📥 카드에 작업을 추가하고 순서대로 정리하세요\n- 📄 Markdown에 추가 메모를 작성하세요.\n- 🔖 더 나은 정리를 위해 라벨을 할당하세요\n- 👥 팀, 친구, 가족과 공유하세요\n- 📎 파일을 첨부하고 Markdown 설명에 포함하세요.\n- 💬 댓글을 사용하여 팀과 토론하세요\n- ⚡ 활동 스트림의 변경 사항을 추적하세요.\n- 🚀 프로젝트를 체계적으로 정리하세요",
+    "Card details" : "카드 세부사항",
     "Add board" : "보드 추가",
     "Select the board to link to a project" : "프로젝트에 연결할 보드를 선택하세요.",
     "Search by board title" : "보드 제목으로 검색",
@@ -186,7 +187,7 @@ OC.L10N.register(
     "Board owner" : "보드 소유자",
     "(Group)" : "(그룹)",
     "(Team)" : "(팀)",
-    "Can edit" : "수정할 수 있음",
+    "Can edit" : "편집 허용",
     "Can share" : "공유할 수 있음",
     "Can manage" : "관리 가능",
     "Owner" : "소유자",
@@ -274,7 +275,6 @@ OC.L10N.register(
     "Todo items" : "작업 항목",
     "{count} comments, {unread} unread" : "댓글 {count}개, 읽지 않음 {unread}개",
     "Edit card title" : "카드 제목 수정",
-    "Card details" : "카드 세부사항",
     "Assign to me" : "나에게 할당",
     "Unassign myself" : "스스로를 할당 해제",
     "Mark as not done" : "완료되지 않은 것으로 표시",
@@ -316,6 +316,7 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "캘린더/작업에 보드 표시",
     "Limit board creation to some groups" : "보드 생성을 일부 그룹으로 제한",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "해당 그룹 외부의 사용자는 자신의 보드를 만들 수 없지만 공유된 보드에서는 계속 작업할 수 있습니다.",
+    "Cancel edit" : "편집 취소",
     "Board details" : "게시판 정보",
     "Edit board" : "게시판 편집",
     "Clone board" : "게시판 복제",
@@ -341,7 +342,6 @@ OC.L10N.register(
     "No due" : "기한 없음",
     "Search for {searchQuery} in all boards" : "모든 게시판에서 {searchQuery}를 검색하세요",
     "No results found" : "결과 없음",
-    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "데크 보드 {name}\n* 마지막 수정일 {lastMod}",
     "{stack} in {board}" : "{board}의 {stack}",
     "Click to expand description" : "설명을 더 보려면 클릭하세요.",
@@ -361,6 +361,7 @@ OC.L10N.register(
     "upcoming cards" : "곧 있을 카드",
     "New card" : "새로운 카드",
     "Due on {date}" : "마감일: {date}",
+    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "내일 – {timeLocale}",
     "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
     "Link to a board" : "보드에 연결",
@@ -374,18 +375,9 @@ OC.L10N.register(
     "Share with a Deck card" : "Deck 카드와 공유",
     "Share {file} with a Deck card" : "Deck 카드와 함께 {file} 공유",
     "Share" : "공유",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 앱 내 <strong>카드 설명</strong>이 변경되었습니다.",
-    "Timeline" : "타임라인",
-    "Share board with a user, group or circle …" : "사용자, 그룹 또는 서클과 보드 공유…",
     "Searching for users, groups and circles …" : "사용자, 그룹, 서클 검색 중…",
     "(Circle)" : "(서클)",
     "Assign to users/groups/circles" : "사용자/그룹/서클에 할당",
-    "Next week" : "다음주",
-    "Next month" : "다음달",
-    "List is empty" : "목록이 비어 있음",
-    "Limit deck usage of groups" : "그룹의 덱 사용 제한",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limiting Deck은 해당 그룹에 속하지 않은 사용자가 자신의 보드를 만드는 것을 차단합니다. 사용자는 공유된 보드에서 계속 작업할 수 있습니다.",
-    "Not completed" : "완성되지 않았다",
     "Filter by completed" : "완료 기준으로 필터링"
 },
 "nplurals=1; plural=0;");
