@@ -39,8 +39,8 @@ OC.L10N.register(
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} at annulladu s'archiviatzione de s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
     "You have removed the due date of card {card}" : "Ci nd'as bogadu sa data de iscadèntzia dae s'ischeda {card}",
     "{user} has removed the due date of card {card}" : "{user} ci nd'at bogadu sa data de iscadèntzia dae s'ischeda {card}",
-    "You have set the due date of card {card} to {after}" : "As impostadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
-    "{user} has set the due date of card {card} to {after}" : "{user} at impostadu sa data de iscadèntzia de sa tèssera {card} a su {after}",
+    "You have set the due date of card {card} to {after}" : "As cunfiguradu sa data de iscadèntzia de s'ischeda {card} a su {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} at cunfiguradu sa data de iscadèntzia de sa tèssera {card} a su {after}",
     "You have updated the due date of card {card} to {after}" : "As agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} as agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
     "You have added the tag {label} to card {card} in list {stack} on board {board}" : "As agiuntu s'eticheta {label} a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
@@ -105,6 +105,7 @@ OC.L10N.register(
     "Path is already shared with this card" : "Su caminu est giai cumpartzidu cun cust'ischeda",
     "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
     "Personal planning and team project organization" : "Pranificatzione personale e organizatzione de su progetu de iscuadra",
+    "Card details" : "Detàllios ischeda",
     "Add board" : "Agiunghe lavagna",
     "Select the board to link to a project" : "Seletziona lavagna de collegare a unu progetu",
     "Search by board title" : "Chirca dae su tìtulu de sa lavagna",
@@ -179,7 +180,7 @@ OC.L10N.register(
     "Board name" : "Nùmene de sa lavagna",
     "Members" : "Membros",
     "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
-    "Upload new files" : "Carriga archìvios noos",
+    "Upload new files" : "Càrriga archìvios noos",
     "Share from Files" : "Cumpartzi dae Archìvios",
     "Add this attachment" : "Agiunghe custu alligongiadu",
     "Show in Files" : "Mustra in Archìvios",
@@ -214,16 +215,16 @@ OC.L10N.register(
     "Add Attachment" : "Agiunghe alligongiadu",
     "Write a description …" : "Iscrie una descritzione ...",
     "Choose attachment" : "Sèbera un'alligongiadu",
-    "Set a due date" : "Imposta iscadèntzia",
+    "Set a due date" : "Cunfigura data de iscadèntzia",
     "Remove due date" : "Boga s'iscadèntzia",
     "Mark as done" : "Marca comente cumpletadu",
     "Unarchive card" : "Ischeda no archiviada",
     "Archive card" : "Archìviu no archiviadu",
     "Select Date" : "Seletziona data",
     "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
+    "Create a new tag:" : "Crea un'eticheta noa:",
     "(group)" : "(grupu)",
     "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
-    "Card details" : "Detàllios ischeda",
     "Assign to me" : "Assigna a mie",
     "Unassign myself" : "Annulla s'assignatzione a mie",
     "Delete card" : "Cantzella ischeda",
@@ -233,11 +234,13 @@ OC.L10N.register(
     "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
     "Action" : "Atzione",
     "Search" : "Chirca",
+    "Show help dialog" : "Mustra su diàlogu de agiudu",
     "All boards" : "Totu is lavagnas",
     "Archived boards" : "Lavagnas archiviadas",
     "Shared with you" : "Cumpartzidu cun tegus",
     "Use bigger card view" : "Imprea bista cun ischedas prus mannas",
     "Show boards in calendar/tasks" : "Mustra lavagnas in calendàriu/fainas",
+    "Cancel edit" : "Annulla modìfica",
     "Board details" : "Detàllios lavagna",
     "Edit board" : "Modìfica lavagna",
     "Clone board" : "Clona lavagna",
@@ -271,6 +274,7 @@ OC.L10N.register(
     "Close" : "Serra",
     "No upcoming cards" : "Peruna ischeda abarrada",
     "upcoming cards" : "ischedas abarradas",
+    "New card" : "Carta noa",
     "Link to a board" : "Collega a una tabella",
     "Link to a card" : "Collega a un'ischeda",
     "Create a card" : "Crea un'ischeda",
@@ -282,16 +286,8 @@ OC.L10N.register(
     "Share with a Deck card" : "Cumpartzi cun un'ischeda deck",
     "Share {file} with a Deck card" : "Cumpartzi {file} cun un'ischeda de deck",
     "Share" : "Cumpartzi",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Sa <strong>descritzione de un'ischeda</strong> in intro de s'aplicatzione Deck app est istada cambiada",
-    "Timeline" : "Fusu oràriu",
-    "Share board with a user, group or circle …" : "Cumpartzi lavagna cun un'utente, grupu o tropa...",
     "Searching for users, groups and circles …" : "Chirchende utentes, grupos e tropas ...",
     "(Circle)" : "(Giru)",
-    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas",
-    "Next week" : "Sa chida chi benit",
-    "Next month" : "Su mese chi benit",
-    "List is empty" : "Sa lista est bòida",
-    "Limit deck usage of groups" : "Mìnima s'impreu de deck de is grupos",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Su de minimare su deck at a impedire a is utentes chi non faghent parte de cuddos grupos de si creare lavagnas pròpias. Is utentes ant a èssere ancora capassos de traballare in is lavagnas chi fiant istadas cumpartzidas cun issos etotu,"
+    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas"
 },
 "nplurals=2; plural=(n != 1);");
