@@ -105,6 +105,7 @@ OC.L10N.register(
     "Path is already shared with this card" : "Pot je že povezana s to nalogo",
     "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
     "Personal planning and team project organization" : "Osebno načrtovanje nalog in organizacija skupinskih projektov",
+    "Card details" : "Podrobnosti naloge",
     "Add board" : "Dodaj zbirko",
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
@@ -129,10 +130,13 @@ OC.L10N.register(
     "Archived cards" : "Arhivirane naloge",
     "Add list" : "Dodaj seznam",
     "List name" : "Ime seznama",
+    "Active filters" : "Dejavni filtri",
     "Apply filter" : "Uveljavi filter",
     "Filter by tag" : "Filtriraj po oznaki",
     "Filter by assigned user" : "Filtriraj po dodeljenem uporabniku",
     "Unassigned" : "Nedodeljeno",
+    "Filter by status" : "Filtri po stanju",
+    "Open and completed" : "Odprto in končano",
     "Open" : "Odpri",
     "Completed" : "Končano",
     "Filter by due date" : "Filtriraj po datumu preteka",
@@ -142,6 +146,8 @@ OC.L10N.register(
     "Next 30 days" : "Naslednjih 30 dni",
     "No due date" : "Ni datuma preteka",
     "Clear filter" : "Počisti filter",
+    "View Modes" : "Načini pogleda",
+    "Toggle View Modes" : "Preklopi načine pogleda",
     "Hide archived cards" : "Skrij arhivirane naloge",
     "Show archived cards" : "Prikaži arhivirane naloge",
     "Toggle compact mode" : "Preklopi način prikaza",
@@ -237,7 +243,6 @@ OC.L10N.register(
     "Todo items" : "Naloge",
     "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
     "Edit card title" : "Uredi naslov naloge",
-    "Card details" : "Podrobnosti naloge",
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
     "Mark as not done" : "Označi kot Ni končano",
@@ -269,6 +274,7 @@ OC.L10N.register(
     "Shared with you" : "V souporabi z vami",
     "Use bigger card view" : "Uporabi povečan pogled nalog",
     "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
+    "Cancel edit" : "Prekliči urejanje",
     "Board details" : "Podrobnosti zbirke",
     "Edit board" : "Uredi zbirko",
     "Clone board" : "Kloniraj zbirko",
@@ -292,7 +298,6 @@ OC.L10N.register(
     "No due" : "Ni datuma preteka",
     "Search for {searchQuery} in all boards" : "Poišči {searchQuery} med vsemi zbirkami nalog.",
     "No results found" : "Ni najdenih zadetkov",
-    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "{stack} in {board}" : "{stack} v {board}",
     "Click to expand comment" : "Kliknite za razširitev opombe",
     "Create a new card" : "Ustvari novo nalogo",
@@ -306,6 +311,7 @@ OC.L10N.register(
     "upcoming cards" : "prihajajoče naloge",
     "New card" : "Nova naloga",
     "Due on {date}" : "Poteče {date}",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
     "Later today – {timeLocale}" : "Danes – {timeLocale}",
     "Link to a board" : "Povezava do zbirke",
@@ -319,17 +325,8 @@ OC.L10N.register(
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
     "Share" : "Souporaba",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
-    "Timeline" : "Časovnica",
-    "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
     "Searching for users, groups and circles …" : "Iskanje uporabnikov, skupin in krogov ...",
     "(Circle)" : "(Krog)",
-    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
-    "Next week" : "Naslednji teden",
-    "Next month" : "Naslednji mesec",
-    "List is empty" : "Seznam je prazen",
-    "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
-    "Not completed" : "Ni končano"
+    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
