@@ -4,6 +4,14 @@ OC.L10N.register(
     "Finished" : "Završeno",
     "copy" : "kopiraj",
     "Done" : "Done",
+    "The file was uploaded" : "Fajl je otpremljen",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fajl za otpremljivanje premašuje upload_max_filesize direktivu u php.ini",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fajl za otpremanje premašuje MAX_FILE_SIZE navedenu u HTML obrascu",
+    "The file was only partially uploaded" : "Fajl je parcijalno otpremljen",
+    "No file was uploaded" : "Nijedan fajl nije otpremljen",
+    "Missing a temporary folder" : "Nedostaje privremena fascikla",
+    "Could not write file to disk" : "Ne mogu da upišem fajl na disk",
+    "A PHP extension stopped the file upload" : "PHP ekstenzija je zaustavila otpremanje fajla",
     "Add board" : "Dodaj tablu",
     "Move card" : "Premesti karticu",
     "Cancel" : "Otkaži",
