@@ -116,6 +116,7 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "无效日期，日期格式必须为 YYYY-MM-DD",
     "Personal planning and team project organization" : "个人规划和团队项目安排",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "看板应用程序是一个看板风格的管理工具，旨在为与Nextcloud集成的团队进行个人规划和项目管理。\n\n\n- 📥 添加您的任务到卡片并将之整理好\n- 📄 用Markdown写下额外的注释\n- 🔖 分配标签以更好地管理您的工作\n- 👥 与您的团队、朋友或家人分享\n- 📎 附件文件并将其嵌入到您的Markdown描述中\n- 💬 使用评论与您的团队沟通\n- ⚡ 在活动流中跟踪变更情况\n- 🚀 让您的项目井井有条",
+    "Card details" : "卡片详情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
@@ -175,7 +176,7 @@ OC.L10N.register(
     "Undo" : "撤消",
     "Deleted cards" : "已删除的卡片",
     "No participants found" : "未找到参与者",
-    "Board owner" : "面板拥有者",
+    "Board owner" : "面板所有者",
     "(Group)" : "（群组）",
     "Can edit" : "可以编辑",
     "Can share" : "可以共享",
@@ -259,7 +260,6 @@ OC.L10N.register(
     "Todo items" : "待办事项",
     "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
     "Edit card title" : "编辑卡片标题",
-    "Card details" : "卡片详情",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
     "Mark as not done" : "标记为未完成",
@@ -294,6 +294,7 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "在日历/任务中显示看板",
     "Limit board creation to some groups" : "限制某些组可以创建看板",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
+    "Cancel edit" : "取消编辑",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
     "Clone board" : "克隆面板",
@@ -319,7 +320,6 @@ OC.L10N.register(
     "No due" : "没有到期的",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
     "No results found" : "未找到结果",
-    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "看板{name}\n* 最后修改于{lastMod}",
     "{stack} in {board}" : "{stack} 于 {board}",
     "Click to expand description" : "点击展开描述",
@@ -339,6 +339,7 @@ OC.L10N.register(
     "upcoming cards" : "即将到来的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "于 {date} 到期 ",
+    "This weekend – {timeLocale}" : "本周末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
     "Later today – {timeLocale}" : "今日稍晚 – {timeLocale}",
     "Link to a board" : "链接到一个面板",
@@ -352,17 +353,8 @@ OC.L10N.register(
     "Share with a Deck card" : "分享给一张看板卡片",
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "看板应用中的 <strong>卡片描述</strong> 已改变",
-    "Timeline" : "时间线",
-    "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
     "Searching for users, groups and circles …" : "正在搜索用户、群组和圈子 ......",
     "(Circle)" : "（圈子）",
-    "Assign to users/groups/circles" : "指派给用户/群组/圈子",
-    "Next week" : "下周",
-    "Next month" : "下月",
-    "List is empty" : "列表为空",
-    "Limit deck usage of groups" : "按群组限制看板的使用权",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制看板的使用权后，不在指定群组中的用户将不能新建面板，但仍可使用已共享给他们的面板。",
-    "Not completed" : "没完成"
+    "Assign to users/groups/circles" : "指派给用户/群组/圈子"
 },
 "nplurals=1; plural=0;");
