@@ -120,6 +120,7 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，日期格式必須為 YYYY-MM-DD",
     "Personal planning and team project organization" : "個人規劃與團隊專案組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
+    "Card details" : "卡片詳細資訊",
     "Add board" : "新增佈告欄",
     "Select the board to link to a project" : "選取要連結到專案的佈告欄",
     "Search by board title" : "按佈告欄標題搜尋",
@@ -274,7 +275,6 @@ OC.L10N.register(
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
     "Edit card title" : "編輯卡片標題",
-    "Card details" : "卡片詳細資訊",
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
     "Mark as not done" : "標記為未完成",
@@ -316,6 +316,8 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
     "Limit board creation to some groups" : "限制僅某些群組可建立看板",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
+    "Cancel edit" : "取消編輯",
+    "Save board" : "儲存佈告欄",
     "Board details" : "佈告欄詳細資訊",
     "Edit board" : "編輯佈告欄",
     "Clone board" : "再製佈告欄",
@@ -341,7 +343,6 @@ OC.L10N.register(
     "No due" : "無到期日",
     "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
     "No results found" : "找不到結果",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
     "{stack} in {board}" : "{stack} 於 {board}",
     "Click to expand description" : "點擊展開描述",
@@ -361,6 +362,7 @@ OC.L10N.register(
     "upcoming cards" : "接下來的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
     "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到佈告欄",
@@ -374,18 +376,9 @@ OC.L10N.register(
     "Share with a Deck card" : "與 Deck 卡片分享",
     "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的<strong>卡片描述</strong>已變更",
-    "Timeline" : "時間軸",
-    "Share board with a user, group or circle …" : "與使用者、群組或小圈圈分享佈告欄……",
     "Searching for users, groups and circles …" : "搜尋使用者、群組與小圈圈……",
     "(Circle)" : "（小圈圈）",
     "Assign to users/groups/circles" : "分配給使用者／群組／小圈圈",
-    "Next week" : "下週",
-    "Next month" : "下個月",
-    "List is empty" : "清單為空",
-    "Limit deck usage of groups" : "限制群組的 Deck 使用",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將會阻止不屬於這些群組的使用者建立自己的佈告欄。使用者仍然可以在與他們分享的佈告欄上工作。",
-    "Not completed" : "未完成",
     "Filter by completed" : "按已完成篩選"
 },
 "nplurals=1; plural=0;");
