@@ -1,27 +1,7 @@
 <?php
 /**
- * @copyright Copyright (c) 2016 Julius Härtl <jus@bitgrid.net>
- *
- * @copyright Copyright (c) 2019, Alexandru Puiu (alexpuiu20@yahoo.com)
- *
- * @author Julius Härtl <jus@bitgrid.net>
- * @author Maxence Lange <maxence@artificial-owl.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Service;
@@ -60,6 +40,7 @@ class CardService {
 	private StackMapper $stackMapper;
 	private BoardMapper $boardMapper;
 	private LabelMapper $labelMapper;
+	private LabelService $labelService;
 	private PermissionService $permissionService;
 	private BoardService $boardService;
 	private NotificationHelper $notificationHelper;
@@ -81,6 +62,7 @@ class CardService {
 		StackMapper $stackMapper,
 		BoardMapper $boardMapper,
 		LabelMapper $labelMapper,
+		LabelService $labelService,
 		PermissionService $permissionService,
 		BoardService $boardService,
 		NotificationHelper $notificationHelper,
@@ -101,6 +83,7 @@ class CardService {
 		$this->stackMapper = $stackMapper;
 		$this->boardMapper = $boardMapper;
 		$this->labelMapper = $labelMapper;
+		$this->labelService = $labelService;
 		$this->permissionService = $permissionService;
 		$this->boardService = $boardService;
 		$this->notificationHelper = $notificationHelper;
@@ -369,8 +352,34 @@ class CardService {
 		}
 		$card->setDescription($description);
 
-
+		// @var Card $card
 		$card = $this->cardMapper->update($card);
+		$oldBoardId = $this->stackMapper->findBoardId($changes->getBefore()->getStackId());
+		$boardId = $this->cardMapper->findBoardId($card->getId());
+		if($boardId !== $oldBoardId) {
+			$stack = $this->stackMapper->find($card->getStackId());
+			$board = $this->boardService->find($this->cardMapper->findBoardId($card->getId()));
+			$boardLabels = $board->getLabels() ?? [];
+			foreach($card->getLabels() as $cardLabel) {
+				$this->removeLabel($card->getId(), $cardLabel->getId());
+				$label = $this->labelMapper->find($cardLabel->getId());
+				$filteredLabels = array_values(array_filter($boardLabels, fn ($item) => $item->getTitle() === $label->getTitle()));
+				// clone labels that are assigned to card but don't exist in new board
+				if (empty($filteredLabels)) {
+					if ($this->permissionService->getPermissions($boardId)[Acl::PERMISSION_MANAGE] === true) {
+						$newLabel = $this->labelService->create($label->getTitle(), $label->getColor(), $board->getId());
+						$boardLabels[] = $label;
+						$this->assignLabel($card->getId(), $newLabel->getId());
+					}
+				} else {
+					$this->assignLabel($card->getId(), $filteredLabels[0]->getId());
+				}
+			}
+			$board->setLabels($boardLabels);
+			$this->boardMapper->update($board);
+			$this->changeHelper->boardChanged($board->getId());
+		}
+
 		if ($resetDuedateNotification) {
 			$this->notificationHelper->markDuedateAsRead($card);
 		}
